@@ -122,41 +122,40 @@ impl<K: Hash + Ord> SearchIndex<K> {
             // relevant autocompletions are returned:
             let autocompletions: Vec<&String> = self.b_tree_map
                 // Get matching keywords starting with (partial) keyword string:
-                .range(String::from(&last_keyword)..)
+                .range(last_keyword.to_string()..)
                 // We did not specify an end bound for our `range` function (see
                 // above.) `range` will return _every_ keyword greater than the
                 // supplied keyword. The below `take_while` will effectively
                 // break iteration when we reach a keyword that does not start
                 // with our supplied (partial) keyword.
-                .take_while(|(key, _value)| key.starts_with(&last_keyword))
+                .take_while(|(keyword, _keys)| keyword.starts_with(&last_keyword))
                 // If the index's keyword matches the user's keyword, don't
                 // return it as a result. For example, if the user's keyword was
                 // "new" (as in New York), do not return "new" as an
                 // auto-completed keyword:
-                // .filter(|(key, _value)| *key != keyword)
-                // Only return `maximum_keys_per_keyword` number of keywords:
-                .take(self.maximum_keys_per_keyword)
+                // .filter(|(key, _value)| *key != &last_keyword)
                 // Only keep this autocompletion if hasn't already been used as
                 // a keyword:
                 .filter(|(keyword, _keys)| !keywords.contains(keyword))
                 // Only keep this autocompletion if it contains a key that the
                 // search results contain:
                 .filter(|(_keyword, keys)|
-                    search_results.is_empty() || keys.iter().any(|key| search_results.contains(key))
+                    search_results.is_empty() ||
+                        keys.iter().any(|key| search_results.contains(key))
                 ) // filter
                 // Only return `maximum_autocomplete_options` number of
                 // keywords:
                 .take(*maximum_autocomplete_options)
-                // `internal_autocomplete_keyword` returns a key-value pair.
-                // We're autocompleting the key, so discard the value:
-                .map(|(keyword, _keys)| keyword)
+                // `range` returns a key-value pair. We're autocompleting the
+                // key (keyword), so discard the value (record key):
+                .map(|(key, _value)| key)
                 // Collect all keyword autocompletions into a `Vec`:
                 .collect();
 
             // Push a blank placeholder onto the end of the keyword list. We
             // will be putting our autocompletions for the last keyword into
             // this spot:
-            keywords.push(String::from(""));
+            keywords.push("".to_string());
 
             // Build autocompleted search strings from the autocompletions
             // derived from the last keyword:
@@ -169,7 +168,7 @@ impl<K: Hash + Ord> SearchIndex<K> {
                     // Remove previous autocompleted last keyword from list:
                     keywords.pop();
                     // Add current autocompleted last keyword to end of list:
-                    keywords.push(String::from(*last_keyword));
+                    keywords.push(last_keyword.to_string());
                     // Join all keywords together into a single `String` using a
                     // space delimiter:
                     keywords.join(" ")
